@@ -2,7 +2,7 @@
 # -*- coding: utf-8 -*-
 #
 #--------------------------------------------------------------------------------
-#www2sms.py v1.1.3
+#www2sms.py v1.1.4
 #Copyright Bjoern Olausson
 #--------------------------------------------------------------------------------
 #This program is free software; you can redistribute it and/or modify
@@ -23,17 +23,17 @@
 #--------------------------------------------------------------------------------
 #
 
-import os, errno, pwd, sys, math, sqlite3, time, calendar, evolution, re, socket
-import ctypes, uuid, glib, gobject
+import os, errno, pwd, sys, math, sqlite3, time, calendar, re, socket
+import ctypes, uuid
+from PyQt4.QtGui import QApplication
 from PyQt4 import QtCore
-from PyQt4.QtGui import QApplication, QMainWindow, QDialog, QPushButton, QMessageBox, QPixmap
+from PyQt4.QtGui import QMainWindow, QDialog, QPushButton, QMessageBox, QPixmap
+import www2sms_providers
 from www2sms_gui_main import Ui_MainWindow
 from www2sms_gui_widget_account import Ui_FormAccount
 from www2sms_gui_dialog_progress import Ui_Form_Progress
-import www2sms_providers
 
-
-VERSION = "v1.1.3"
+VERSION = "v1.1.4"
 USER = pwd.getpwuid(os.getuid())[0]
 CONFIG_DIR = "/home/%s/MyDocs/www2sms" %(USER)
 
@@ -543,10 +543,12 @@ mk_db()
 conn = sqlite3.connect('www2sms.db')
 c = conn.cursor()
 
+
 if __name__ == "__main__":
 	# Someone is launching this directly
 	# Create the QApplication
 	app = QApplication(sys.argv)
+	import gobject, glib, evolution
 	#The Status Form
 	#Stat = FormPro()
 	#The Main window
